@@ -10,10 +10,10 @@
 # ================ 定位操作 =====================
 from rest_framework.views import APIView
 
-from utils.j_dict import JDict
 from xj_role.services.permission_service import PermissionService
 from xj_user.services.user_service import UserService
 from ..services.location_service import LocationService
+from ..utils.j_dict import JDict
 from ..utils.model_handle import *
 
 
